==> esdl-0.2.0.crate: esdl-0.2.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file. See [conventional commits](https://www.conventionalcommits.org/) for commit guidelines.

- - -
## [0.2.0](https://github.com/thalo-rs/esdl/compare/0.1.0..0.2.0) - 2022-01-25
#### Features
- add parsing options for `Schema` - ([921b3c7](https://github.com/thalo-rs/esdl/commit/921b3c77349c5038336e29ff74cbacc6f9ae1242)) - [@tqwewe](https://github.com/tqwewe)
- add serde derives to schema - ([8914873](https://github.com/thalo-rs/esdl/commit/891487365450b0d845f2bf46f597651baead507a)) - [@tqwewe](https://github.com/tqwewe)
#### Miscellaneous Chores
- add CHANGELOG.md - ([5c1abc4](https://github.com/thalo-rs/esdl/commit/5c1abc4035a468ddbb218805466c2ff5a0114488)) - [@tqwewe](https://github.com/tqwewe)
- add bump books to cog.toml - ([195c86c](https://github.com/thalo-rs/esdl/commit/195c86c6d64bc97232a81d92ec3997448c39c579)) - [@tqwewe](https://github.com/tqwewe)
- revert "chore: rename to esl" - ([15ad3da](https://github.com/thalo-rs/esdl/commit/15ad3da39ceac64a09d1730ba3faad8d8a42cf0f)) - [@tqwewe](https://github.com/tqwewe)
- rename to esl - ([b0a3d21](https://github.com/thalo-rs/esdl/commit/b0a3d21a70ff56737d513ffcf58150c0eaf70b43)) - [@tqwewe](https://github.com/tqwewe)
- - -

## [0.1.0](https://github.com/thalo-rs/esdl/compare/52dd3bbf938b81e6ff8e5b99b6d84243ecf9fcf8..0.1.0) - 2022-01-25
#### Bug Fixes
- event suffix in command events - ([e240973](https://github.com/thalo-rs/esdl/commit/e24097328b5371da9d37115220867388236d1937)) - [@tqwewe](https://github.com/tqwewe)
- incorrect reference to event in return type - ([8ef5eec](https://github.com/thalo-rs/esdl/commit/8ef5eecf17ddba05c3bc930112740156dcfc8e13)) - [@tqwewe](https://github.com/tqwewe)
#### Documentation
- add scalar types and syntax to README.md - ([3e2e90d](https://github.com/thalo-rs/esdl/commit/3e2e90d3f243ec995b6a7d1146a14b4c93bd94b0)) - [@tqwewe](https://github.com/tqwewe)
#### Features
- add parsing options for `Schema` - ([921b3c7](https://github.com/thalo-rs/esdl/commit/921b3c77349c5038336e29ff74cbacc6f9ae1242)) - [@tqwewe](https://github.com/tqwewe)
- add serde derives to schema - ([8914873](https://github.com/thalo-rs/esdl/commit/891487365450b0d845f2bf46f597651baead507a)) - [@tqwewe](https://github.com/tqwewe)
- add scalar `Timestamp` - ([722af3c](https://github.com/thalo-rs/esdl/commit/722af3c52f30346f5cdb46f50bc4fcf9e48707e1)) - [@tqwewe](https://github.com/tqwewe)
- use associated error type for command trait - ([ee0849b](https://github.com/thalo-rs/esdl/commit/ee0849bbe95b7acfd5a056f77f184290d74f99b8)) - [@tqwewe](https://github.com/tqwewe)
#### Miscellaneous Chores
- add bump books to cog.toml - ([195c86c](https://github.com/thalo-rs/esdl/commit/195c86c6d64bc97232a81d92ec3997448c39c579)) - [@tqwewe](https://github.com/tqwewe)
- revert "chore: rename to esl" - ([15ad3da](https://github.com/thalo-rs/esdl/commit/15ad3da39ceac64a09d1730ba3faad8d8a42cf0f)) - [@tqwewe](https://github.com/tqwewe)
- rename to esl - ([b0a3d21](https://github.com/thalo-rs/esdl/commit/b0a3d21a70ff56737d513ffcf58150c0eaf70b43)) - [@tqwewe](https://github.com/tqwewe)
- add meta information to Cargo.toml - ([87e1ec3](https://github.com/thalo-rs/esdl/commit/87e1ec397c9b40dd1dfb3b92ea54d4464a037d9d)) - [@tqwewe](https://github.com/tqwewe)
- delete example.esdl - ([ce264de](https://github.com/thalo-rs/esdl/commit/ce264ded427384975136f29fc122aa3f19ad4ccf)) - [@tqwewe](https://github.com/tqwewe)
- - -

Changelog generated by [cocogitto](https://github.com/cocogitto/cocogitto).

==> esdl-0.2.1.crate: esdl-0.2.1/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file. See [conventional commits](https://www.conventionalcommits.org/) for commit guidelines.

- - -
## [0.2.1](https://github.com/thalo-rs/esdl/compare/0.2.0..0.2.1) - 2022-01-27
#### Features
- implement `Serialize` and `Deserialize` on type structs - ([97de0a0](https://github.com/thalo-rs/esdl/commit/97de0a01e097f64f1fcd778d7c6ac735439ee6fb)) - Mike Shearer
#### Refactoring
- run cargo fmt - ([d586634](https://github.com/thalo-rs/esdl/commit/d586634bade768fb6c818a79b3d15db3d3fac876)) - [@tqwewe](https://github.com/tqwewe)
- - -

## [0.2.0](https://github.com/thalo-rs/esdl/compare/0.1.0..0.2.0) - 2022-01-25
#### Features
- add parsing options for `Schema` - ([921b3c7](https://github.com/thalo-rs/esdl/commit/921b3c77349c5038336e29ff74cbacc6f9ae1242)) - [@tqwewe](https://github.com/tqwewe)
- add serde derives to schema - ([8914873](https://github.com/thalo-rs/esdl/commit/891487365450b0d845f2bf46f597651baead507a)) - [@tqwewe](https://github.com/tqwewe)
#### Miscellaneous Chores
- add CHANGELOG.md - ([5c1abc4](https://github.com/thalo-rs/esdl/commit/5c1abc4035a468ddbb218805466c2ff5a0114488)) - [@tqwewe](https://github.com/tqwewe)
- add bump books to cog.toml - ([195c86c](https://github.com/thalo-rs/esdl/commit/195c86c6d64bc97232a81d92ec3997448c39c579)) - [@tqwewe](https://github.com/tqwewe)
- revert "chore: rename to esl" - ([15ad3da](https://github.com/thalo-rs/esdl/commit/15ad3da39ceac64a09d1730ba3faad8d8a42cf0f)) - [@tqwewe](https://github.com/tqwewe)
- rename to esl - ([b0a3d21](https://github.com/thalo-rs/esdl/commit/b0a3d21a70ff56737d513ffcf58150c0eaf70b43)) - [@tqwewe](https://github.com/tqwewe)
- - -

## [0.1.0](https://github.com/thalo-rs/esdl/compare/52dd3bbf938b81e6ff8e5b99b6d84243ecf9fcf8..0.1.0) - 2022-01-25
#### Bug Fixes
- event suffix in command events - ([e240973](https://github.com/thalo-rs/esdl/commit/e24097328b5371da9d37115220867388236d1937)) - [@tqwewe](https://github.com/tqwewe)
- incorrect reference to event in return type - ([8ef5eec](https://github.com/thalo-rs/esdl/commit/8ef5eecf17ddba05c3bc930112740156dcfc8e13)) - [@tqwewe](https://github.com/tqwewe)
#### Documentation
- add scalar types and syntax to README.md - ([3e2e90d](https://github.com/thalo-rs/esdl/commit/3e2e90d3f243ec995b6a7d1146a14b4c93bd94b0)) - [@tqwewe](https://github.com/tqwewe)
#### Features
- add parsing options for `Schema` - ([921b3c7](https://github.com/thalo-rs/esdl/commit/921b3c77349c5038336e29ff74cbacc6f9ae1242)) - [@tqwewe](https://github.com/tqwewe)
- add serde derives to schema - ([8914873](https://github.com/thalo-rs/esdl/commit/891487365450b0d845f2bf46f597651baead507a)) - [@tqwewe](https://github.com/tqwewe)
- add scalar `Timestamp` - ([722af3c](https://github.com/thalo-rs/esdl/commit/722af3c52f30346f5cdb46f50bc4fcf9e48707e1)) - [@tqwewe](https://github.com/tqwewe)
- use associated error type for command trait - ([ee0849b](https://github.com/thalo-rs/esdl/commit/ee0849bbe95b7acfd5a056f77f184290d74f99b8)) - [@tqwewe](https://github.com/tqwewe)
#### Miscellaneous Chores
- add bump books to cog.toml - ([195c86c](https://github.com/thalo-rs/esdl/commit/195c86c6d64bc97232a81d92ec3997448c39c579)) - [@tqwewe](https://github.com/tqwewe)
- revert "chore: rename to esl" - ([15ad3da](https://github.com/thalo-rs/esdl/commit/15ad3da39ceac64a09d1730ba3faad8d8a42cf0f)) - [@tqwewe](https://github.com/tqwewe)
- rename to esl - ([b0a3d21](https://github.com/thalo-rs/esdl/commit/b0a3d21a70ff56737d513ffcf58150c0eaf70b43)) - [@tqwewe](https://github.com/tqwewe)
- add meta information to Cargo.toml - ([87e1ec3](https://github.com/thalo-rs/esdl/commit/87e1ec397c9b40dd1dfb3b92ea54d4464a037d9d)) - [@tqwewe](https://github.com/tqwewe)
- delete example.esdl - ([ce264de](https://github.com/thalo-rs/esdl/commit/ce264ded427384975136f29fc122aa3f19ad4ccf)) - [@tqwewe](https://github.com/tqwewe)
- - -

Changelog generated by [cocogitto](https://github.com/cocogitto/cocogitto).
